@@ -2,7 +2,7 @@ from setuptools import setup, find_packages
 
 setup(
     name="YunxinServerApiSigner",
-    version="1.0.1",
+    version="1.0.2",
     author="netease.jiaojian1",
     author_email="netease.jiaojian1@hotmail.com",
     description="云信服务端api签名器",
@@ -11,7 +11,7 @@ setup(
     install_requires=['pandas', 'openpyxl', ],
     entry_points={
         'console_scripts': [
-            'YunxinServerApiSigner=YunxinServerApiSigner',
+            'YunxinServerApiSigner=YunxinServerApiSigner.main:main',
         ]
     },
 )
\ No newline at end of file
